/**
 * Block dependencies
 */
import './editor.scss';

/**
 * Internal block libraries
 */
const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const { TextControl, Button } = wp.components;
const { Component } = wp.element;

/**
 * essgrid Editor Element
 */
export class EssGrid extends Component {

    constructor() {
        super( ...arguments );
        const { attributes: { text, gridTitle } } = this.props;
        this.state = { text: text ?? '', gridTitle: gridTitle ?? '' };
        window.essgrid_react = {};
    }

    render() {
        const { attributes: { text,gridTitle }, setAttributes } = this.props;

        const openDialog = () => {
          window.essgrid_react = this;
          ESG.SC.openBlockSettings({editor:'gutenberg'});
        }

        const openEdit = () => {
          window.essgrid_react = this;

          var shortcode = this.state.text,
              attributes = {};

          if ( typeof shortcode === "undefined" ) return false;

          var matches = shortcode.match(/[\w-]+=".+?"/g);
          if ( !matches ) return false;

          matches.forEach(function(attribute) {
              attribute = attribute.match(/([\w-]+)="(.+?)"/);
              attributes[attribute[1]] = attribute[2];
          });

          if ( typeof attributes.alias === "undefined" ) return false;

          window.open("admin.php?page=essential-grid&view=grid-create&alias=" + encodeURI(attributes.alias), '_blank');
        }

        return (
          <div className="essgrid_block">
                  <span>{gridTitle}&nbsp;</span>
                  <TextControl
                    className="grid_slug"
                    value={ text ?? '' }
                    onChange={ ( text ) => setAttributes( { text } ) }
                    />
                  <Button
                    variant="secondary"
                    onClick={ openEdit }
                    className="grid_edit_button editor_icon dashicons dashicons-edit"
                    >
                  </Button>
                  <Button
                    variant="secondary"
                    onClick={ openDialog }
                    className="grid_edit_button"
                    >
                    {__( 'Select Grid', 'essgrid' )}
                  </Button>
          </div>
        );
    }
}


/**
 * Register block
 */
export default registerBlockType(
    'themepunch/essgrid',
    {
        title: __( 'Essential Grid Quick Builder', 'essgrid' ),
        description: __( 'Add your Essential Grid', 'essgrid' ),
        category: 'essgrid',
        icon: {
          src:  'screenoptions',
          background: '#c90000',
          color: 'white'
        },
        keywords: [
          __( 'image', 'essgrid' ),
          __( 'gallery', 'essgrid' ),
          __( 'grid', 'essgrid' ),
        ],
        example: {
          attributes: {
            cover: EssGridOptions.pluginurl + "admin/includes/gutenberg-blocks/build/images/esg-minigif.gif",
            text: '',
            gridTitle: '',
          },
        },
        attributes: {
          text: {
            selector: '.essgrid',
            type: 'string',
            source: 'text',
          },
          gridTitle: {
            selector: '.essgrid',
            type: 'string',
            source: 'attribute',
            attribute: 'data-gridtitle',
          },
          cover: {
            default: false
          }
        },
        edit: props => {
          const { attributes: { cover } } = props;
          return (
            cover ?
              <center><img src={cover} width={320} height={180}></img></center>
              :
              <div>
                <EssGrid {...props} />
              </div>
          );
        },
        save: props => {
          const { attributes: { text, gridTitle } } = props;
          return (
            <div className="essgrid" data-gridtitle={gridTitle}>
               {text}
            </div>
          );
        },
    },
);
